@@ -1,10 +1,13 @@
 from typing import Dict, Callable, Optional, Type
 
 from cloudrail.knowledge.context.aws.resources.apigatewayv2.api_gateway_v2 import ApiGateway
+from cloudrail.knowledge.context.aws.resources.cloudfront.origin_access_identity import OriginAccessIdentity
+from cloudrail.knowledge.context.aws.resources.dax.dax_cluster import DaxCluster
 from cloudrail.knowledge.context.aws.resources.autoscaling.launch_template import LaunchTemplate
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
 from cloudrail.knowledge.context.aws.resources.cloudfront.cloudfront_distribution_list import CloudFrontDistribution
 from cloudrail.knowledge.context.aws.resources.cloudtrail.cloudtrail import CloudTrail
+from cloudrail.knowledge.context.aws.resources.codebuild.codebuild_project import CodeBuildProject
 from cloudrail.knowledge.context.aws.resources.cloudwatch.cloudwatch_logs_destination import CloudWatchLogsDestination
 from cloudrail.knowledge.context.aws.resources.codebuild.codebuild_report_group import CodeBuildReportGroup
 from cloudrail.knowledge.context.aws.resources.configservice.config_aggregator import ConfigAggregator
@@ -13,15 +16,19 @@ from cloudrail.knowledge.context.aws.resources.ec2.elastic_ip import ElasticIp
 from cloudrail.knowledge.context.aws.resources.ec2.internet_gateway import InternetGateway
 from cloudrail.knowledge.context.aws.resources.ec2.security_group import SecurityGroup
 from cloudrail.knowledge.context.aws.resources.ec2.subnet import Subnet
+from cloudrail.knowledge.context.aws.resources.ec2.transit_gateway import TransitGateway
+from cloudrail.knowledge.context.aws.resources.ec2.transit_gateway_vpc_attachment import TransitGatewayVpcAttachment
 from cloudrail.knowledge.context.aws.resources.ec2.vpc import Vpc
 from cloudrail.knowledge.context.aws.resources.ec2.vpc_endpoint import VpcEndpointInterface
 from cloudrail.knowledge.context.aws.resources.elb.load_balancer import LoadBalancer
 from cloudrail.knowledge.context.aws.resources.elb.load_balancer_listener import LoadBalancerListener
 from cloudrail.knowledge.context.aws.resources.iam.role import Role
+from cloudrail.knowledge.context.aws.resources.iam.iam_instance_profile import IamInstanceProfile
 from cloudrail.knowledge.context.aws.resources.kms.kms_key import KmsKey
 from cloudrail.knowledge.context.aws.resources.lambda_.lambda_function import LambdaFunction
 from cloudrail.knowledge.context.aws.resources.s3.s3_bucket import S3Bucket
-
+from cloudrail.knowledge.context.aws.resources.ec2.route_table import RouteTable
+from cloudrail.knowledge.context.aws.resources.kinesis.kinesis_stream import KinesisStream
 
 class CloudformationAttributesCallableStore:
 
@@ -93,6 +100,12 @@ class CloudformationAttributesCallableStore:
             return api_gateway.api_endpoint
         return None
 
+    @staticmethod
+    def get_dax_cluster_attribute(dax_cluster: DaxCluster, attribute_name: str):
+        if attribute_name == "Arn":
+            return dax_cluster.cluster_arn
+        return None
+
     @staticmethod
     def get_subnet_attribute(subnet: Subnet, attribute_name: str):
         if attribute_name == "AvailabilityZone":
@@ -191,6 +204,43 @@ class CloudformationAttributesCallableStore:
             return lambda_func.get_arn()
         return None
 
+    @staticmethod
+    def get_iam_instance_profile_attribute(iam_instance_profile: IamInstanceProfile, attribute_name: str):
+        if attribute_name == "Arn":
+            return iam_instance_profile.get_arn()
+        return None
+
+    @staticmethod
+    def get_transit_gateway_attribute(transit_gateway: TransitGateway, attribute_name: str):
+        if attribute_name == "Id":
+            return transit_gateway.get_id()
+        return None
+
+    @staticmethod
+    def get_codebuild_project_attribute(codebuild_project: CodeBuildProject, attribute_name: str):
+        if attribute_name == "Arn":
+            return codebuild_project.get_arn()
+        return None
+
+    @staticmethod
+    def get_route_table_attribute(route_table: RouteTable, attribute_name: str):
+        if attribute_name == "RouteTableId":
+            return route_table.get_id()
+        return None
+
+    @staticmethod
+    def get_kinesis_stream_attribute(kinesis_stream: KinesisStream, attribute_name: str):
+        if attribute_name == "Arn":
+            return kinesis_stream.get_arn()
+        return None
+
+    @staticmethod
+    def get_cloudfront_origin_access_idenity_attribute(origin_access_id: OriginAccessIdentity, attribute_name: str):
+        if attribute_name == "Id":
+            return origin_access_id.get_id()
+        if attribute_name == "S3CanonicalUserId":
+            return origin_access_id.s3_canonical_user_id
+        return None
 
 class CloudformationResourceAttributesMapper:
 
@@ -214,7 +264,14 @@ class CloudformationResourceAttributesMapper:
         CloudFrontDistribution: CloudformationAttributesCallableStore.get_cloudfront_distribution_list_attribute,
         VpcEndpointInterface: CloudformationAttributesCallableStore.get_vpc_endpoint_interface_attribute,
         Role: CloudformationAttributesCallableStore.get_iam_role_attribute,
-        LambdaFunction: CloudformationAttributesCallableStore.get_lambda_func_attribute
+        LambdaFunction: CloudformationAttributesCallableStore.get_lambda_func_attribute,
+        CodeBuildProject: CloudformationAttributesCallableStore.get_codebuild_project_attribute,
+        IamInstanceProfile: CloudformationAttributesCallableStore.get_iam_instance_profile_attribute,
+        DaxCluster: CloudformationAttributesCallableStore.get_dax_cluster_attribute,
+        TransitGatewayVpcAttachment: CloudformationAttributesCallableStore.get_transit_gateway_attribute,
+        RouteTable: CloudformationAttributesCallableStore.get_route_table_attribute,
+        KinesisStream: CloudformationAttributesCallableStore.get_kinesis_stream_attribute,
+        OriginAccessIdentity: CloudformationAttributesCallableStore.get_cloudfront_origin_access_idenity_attribute,
     }
 
     @classmethod
