@@ -5,6 +5,7 @@ from cloudrail.knowledge.context.aws.resources.apigatewayv2.api_gateway_v2_vpc_l
 from cloudrail.knowledge.context.aws.resources.networking_config.network_configuration import NetworkConfiguration
 from cloudrail.knowledge.context.aws.resources.networking_config.network_entity import NetworkEntity
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class ApiGateway(NetworkEntity):
@@ -75,5 +76,5 @@ class ApiGateway(NetworkEntity):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'api_gw_name': self.api_gw_name,
+        return {'tags': filter_tags(self.tags), 'api_gw_name': self.api_gw_name,
                 'protocol_type': self.protocol_type}
