@@ -3,6 +3,7 @@ from typing import List
 from cloudrail.knowledge.context.aws.resources.kms.kms_key import KmsKey
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class CloudWatchLogGroup(AwsResource):
@@ -17,7 +18,8 @@ class CloudWatchLogGroup(AwsResource):
     """
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'name': self.name,
+        return {'tags': filter_tags(self.tags),
+                'name': self.name,
                 'kms_encryption': self.kms_encryption,
                 'retention_in_days': self.retention_in_days}
 
