@@ -3,6 +3,7 @@ from typing import List
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
 from cloudrail.knowledge.context.aws.resources.ec2.igw_type import IgwType
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class InternetGateway(AwsResource):
@@ -48,5 +49,6 @@ class InternetGateway(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'vpc_id': self.vpc_id,
+        return {'tags': filter_tags(self.tags),
+                'vpc_id': self.vpc_id,
                 'igw_type': self.igw_type.value}
