@@ -9,6 +9,7 @@ from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
 from cloudrail.knowledge.context.aws.resources.networking_config.network_entity import NetworkEntity
 from cloudrail.knowledge.context.aws.resources.ec2.network_interface import NetworkInterface
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class EcsCluster(AwsResource):
@@ -94,5 +95,5 @@ class EcsCluster(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'cluster_name': self.cluster_name,
+        return {'tags': filter_tags(self.tags), 'cluster_name': self.cluster_name,
                 'is_container_insights_enabled': self.is_container_insights_enabled}
