@@ -31,5 +31,5 @@ class GlacierVaultPolicy(ResourceBasedPolicy):
             return 'S3 Glacier Vault resource policies'
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'vault_arn': self.vault_arn,
+        return {'vault_arn': self.vault_arn,
                 'policy_statements': [statement.to_dict() for statement in self.statements]}
