@@ -8,6 +8,7 @@ from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceNam
 from cloudrail.knowledge.context.aws.resources.networking_config.inetwork_configuration import INetworkConfiguration
 from cloudrail.knowledge.context.aws.resources.networking_config.network_configuration import NetworkConfiguration
 from cloudrail.knowledge.context.aws.resources.networking_config.network_entity import NetworkEntity
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class RedshiftCluster(NetworkEntity, INetworkConfiguration):
@@ -81,7 +82,8 @@ class RedshiftCluster(NetworkEntity, INetworkConfiguration):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'db_name': self.db_name,
+        return {'tags': filter_tags(self.tags),
+                'db_name': self.db_name,
                 'port': self.port,
                 'subnet_group_name': self.subnet_group_name,
                 'security_group_ids': self.network_configuration.security_groups,
