@@ -3,6 +3,7 @@ from cloudrail.knowledge.context.aws.resources.kms.kms_key import KmsKey
 
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class SnsTopic(AwsResource):
@@ -52,6 +53,7 @@ class SnsTopic(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'sns_name': self.sns_name,
+        return {'tags': filter_tags(self.tags),
+                'sns_name': self.sns_name,
                 'encrypted_at_rest': self.encrypted_at_rest,
                 'kms_key': self.kms_key}
