@@ -195,7 +195,9 @@ class AwsScannerContextBuilder(ScannerContextBuilder):
                 route_tables=AliasesDict(*[rt for rt in RouteTableBuilder(account_data_dir, salt).build() if rt.is_main_route_table]),
                 network_acls=AliasesDict(*[nacl for nacl in NetworkAclBuilder(account_data_dir, salt).build() if nacl.is_default]),
                 main_route_table_associations=MainRouteTableAssociationBuilder(account_data_dir, salt).build(),
-            )
+                kms_aliases=KmsAliasBuilder(account_data_dir, salt).build(),
+                resources_tagging_list=ResourceTagMappingListBuilder(account_data_dir, salt).build(),
+                origin_access_identity_list=OriginAccessIdentityBuilder(account_data_dir, salt).build())
 
         accounts = AccountBuilder(account_data_dir, salt).build()
         s3_buckets = S3BucketBuilder(account_data_dir, salt).build()
