@@ -1,5 +1,6 @@
 from typing import List, Optional
 
+from cloudrail.knowledge.context.gcp.resources.compute.gcp_compute_target_proxy import GcpComputeTargetProxy
 from cloudrail.knowledge.context.gcp.resources.constants.gcp_resource_type import GcpResourceType
 from cloudrail.knowledge.context.gcp.resources.gcp_resource import GcpResource
 
@@ -8,15 +9,16 @@ class GcpComputeGlobalForwardingRule(GcpResource):
     """
         Attributes:
             name: (Required) A unique name of the resource.
-            target: (Required) The URL of the target resource to receive the matched traffic.
+            target_identifier: (Required) The URL of the target resource to receive the matched traffic.
     """
 
     def __init__(self,
                  name: str,
-                 target: str):
+                 target_identifier: str):
         super().__init__(GcpResourceType.GOOGLE_COMPUTE_GLOBAL_FORWARDING_RULE)
         self.name: str = name
-        self.target: str = target
+        self.target_identifier: str = target_identifier
+        self.target: Optional[GcpComputeTargetProxy] = None
 
     def get_keys(self) -> List[str]:
         return [self.name, self.project_id]
@@ -42,4 +44,4 @@ class GcpComputeGlobalForwardingRule(GcpResource):
             return 'Compute Global Forwarding Rules'
 
     def to_drift_detection_object(self) -> dict:
-        return {'target': self.target}
+        return {'target': self.target_identifier}
