@@ -1,4 +1,3 @@
-
 from cloudrail.knowledge.context.gcp.resources.compute.gcp_compute_network import GcpComputeNetwork, \
     GcpComputeNetworkRoutingMode
 from cloudrail.knowledge.context.gcp.resources_builders.scanner.base_gcp_scanner_builder import BaseGcpScannerBuilder
@@ -12,5 +11,7 @@ class ComputeNetworkBuilder(BaseGcpScannerBuilder):
     def do_build(self, attributes: dict) -> GcpComputeNetwork:
         routing_mode = attributes['routingConfig'].get('routingMode', 'REGIONAL') if attributes.get('routingConfig') else 'REGIONAL'
         return GcpComputeNetwork(name=attributes['name'],
+                                 network_id=attributes["id"],
+                                 self_link=attributes["selfLink"],
                                  auto_create_subnetworks=attributes.get('autoCreateSubnetworks', True),
                                  routing_mode=GcpComputeNetworkRoutingMode(routing_mode))
