@@ -9,6 +9,8 @@ class ComputeNetworkBuilder(BaseGcpTerraformBuilder):
 
     def do_build(self, attributes: dict) -> GcpComputeNetwork:
         return GcpComputeNetwork(name=attributes['name'],
+                                 network_id=attributes["id"],
+                                 self_link=attributes["self_link"],
                                  auto_create_subnetworks=self._get_known_value(attributes, 'auto_create_subnetworks', True),
                                  routing_mode=GcpComputeNetworkRoutingMode(self._get_known_value(attributes, 'routing_mode', 'REGIONAL')))
 
