@@ -70,9 +70,22 @@ def get_account_id(account_data_dir: str) -> str:
     return load_as_json(filepath)['Account']
 
 
+@functools.lru_cache(maxsize=None)
+def gcp_get_project_id(account_data_dir: str) -> str:
+    filename = 'cloudresourcemanager-v3-projects-get.json'
+    filepath = None
+    for root, _, files in os.walk(account_data_dir):
+        if filename in files:
+            filepath = os.path.join(root, filename)
+            break
+
+    if filepath is None:
+        raise Exception(f'Cannot find {filename} under {account_data_dir}')
+
+    return load_as_json(filepath)['value'][0]['projectId']
+
+
 # --- FILE SYSTEM UTILS
-
-
 def get_subfolder_names(path: str):
     return [d for d in os.listdir(path) if os.path.isdir(os.path.join(path, d))]
 
